#!/bin/bash
readonly texture_compresstion='true'

readonly android_key_path='key.pk8'
readonly android_certificate_path='certificate.pem'

readonly ios_identity_path='xxx'
readonly ios_mobileprovisioning_path='xxx.mobileprovisioning'

# set environment
environment=$(less game.project | grep "^environment = " | cut -d "=" -f2 | sed -e 's/^[[:space:]]*//' | sed -e 's/\r//')
if [ "$1" == "-t" ]; then
	sed -i "s/environment = ${environment}/environment = test/1" game.project
	environment="test"
elif [ "$1" == "-d" ]; then
	sed -i "s/environment = ${environment}/environment = development/1" game.project
	environment="development"
fi

# set archive path
archive_path=$2

# get title from game.project
title=$(less game.project | grep "^title = " | cut -d "=" -f2 | sed -e 's/^[[:space:]]*//' | sed -e 's/\r//')
title_no_space=$(echo -e "${title}" | tr -d '[[:space:]]')

echo "-----------------------------------"
echo "Project: ${title}"
echo "Environment: ${environment}"
echo "-----------------------------------"

if [ ! -f bob.jar ]; then
	echo "Unable to find bob.jar. Download it from d.defold.com."
	exit 1
fi

bob() {
	java -jar bob.jar $@
}

build() {
	platform=$1
	shift 1
	bob --platform ${platform} --archive build $@
}

bundle() {
	platform=$1
	shift 1
	bob --platform ${platform} --bundle-output build/${platform} $@ bundle
}

archive() {
	if [ ! -n "${archive_path}" ] ;then
		echo "No archive path is specified."
	else
		platform=$1
		date=`date +%Y-%m-%d`
		if [ "${platform}" == "armv7-android" ]; then
			echo "file: ${title_no_space}_${date}.apk"
			mv "build/${platform}/${title}/${title}.apk" "${archive_path}/android/${environment}/${title_no_space}_${date}.apk"
		elif [ "${platform}" == "armv7-darwin" ]; then
			echo "file: ${title_no_space}_${date}.ipa"
			mv "build/${platform}/${title}/${title}.ipa" "${archive_path}/ios/${environment}/${title_no_space}_${date}.ipa"
		else
			echo "${title_no_space}_${platform}.zip"
			rm -rf "${title_no_space}_${platform}.zip"
			cd build/${platform}
			zip -r -q "../../${title_no_space}_${platform}.zip" *
			cd ../..
		fi
	fi
}

# resolving reference
# echo -e "[Resolving]"
# bob --email xxxx@kingsoft.com --auth xxxxxxxx resolve

###################
#     android     #
###################
echo "Making android version..."
# clean project
echo -e "[Cleaning]"
bob distclean

# build android
echo -e "[Building]"
rm -rf build
build armv7-android -tc ${texture_compresstion}

# bundle platforms
echo -e "[Bundling]"
bundle armv7-android --private-key ${android_key_path} --certificate ${android_certificate_path} # --variant debug --strip-executable

# archive bundled platforms
echo -e "[Archiving]"
archive armv7-android

###################
#       ios       #
###################
# echo "Making ios version..."
# # clear
# echo -e "[Clear]"
# bob distclean

# # build ios
# echo -e "[Building]"
# rm -rf build
# build armv7-darwin -tc ${texture_compresstion}

# # bundle platforms
# echo -e "[Bundling]"
# bundle armv7-darwin --identity ${ios_identity_path} --mobileprovisioning ${ios_mobileprovisioning_path} # --variant debug --strip-executable

# # archive bundled platforms
# echo -e "[Archiving]"
# archive armv7-darwin
