varying highp vec4 var_position;
varying highp vec3 var_normal;
varying highp vec2 var_texcoord0;

uniform highp sampler2D tex0;
uniform highp vec4 frame_buffer_size;
uniform highp vec4 tint;

vec4 apply_fxaa()
{
	float FXAA_SPAN_MAX = 8.0;
	float FXAA_REDUCE_MUL = 1.0/8.0;
	float FXAA_REDUCE_MIN = 1.0/128.0;

	vec3 rgbNW=texture2D(tex0,var_texcoord0+(vec2(-1.0,-1.0)/frame_buffer_size.xy)).xyz;
	vec3 rgbNE=texture2D(tex0,var_texcoord0+(vec2(1.0,-1.0)/frame_buffer_size.xy)).xyz;
	vec3 rgbSW=texture2D(tex0,var_texcoord0+(vec2(-1.0,1.0)/frame_buffer_size.xy)).xyz;
	vec3 rgbSE=texture2D(tex0,var_texcoord0+(vec2(1.0,1.0)/frame_buffer_size.xy)).xyz;
	vec3 rgbM=texture2D(tex0,var_texcoord0).xyz;

	vec3 luma=vec3(0.299, 0.587, 0.114);
	float lumaNW = dot(rgbNW, luma);
	float lumaNE = dot(rgbNE, luma);
	float lumaSW = dot(rgbSW, luma);
	float lumaSE = dot(rgbSE, luma);
	float lumaM  = dot(rgbM,  luma);

	float lumaMin = min(lumaM, min(min(lumaNW, lumaNE), min(lumaSW, lumaSE)));
	float lumaMax = max(lumaM, max(max(lumaNW, lumaNE), max(lumaSW, lumaSE)));

	vec2 dir;
	dir.x = -((lumaNW + lumaNE) - (lumaSW + lumaSE));
	dir.y =  ((lumaNW + lumaSW) - (lumaNE + lumaSE));

	float dirReduce = max(
		(lumaNW + lumaNE + lumaSW + lumaSE) * (0.25 * FXAA_REDUCE_MUL),
		FXAA_REDUCE_MIN);

	float rcpDirMin = 1.0/(min(abs(dir.x), abs(dir.y)) + dirReduce);

	dir = min(vec2( FXAA_SPAN_MAX,  FXAA_SPAN_MAX),
	max(vec2(-FXAA_SPAN_MAX, -FXAA_SPAN_MAX),
	dir * rcpDirMin)) / frame_buffer_size.xy;

	vec3 rgbA = (1.0/2.0) * (
		texture2D(tex0, var_texcoord0.xy + dir * (1.0/3.0 - 0.5)).xyz +
		texture2D(tex0, var_texcoord0.xy + dir * (2.0/3.0 - 0.5)).xyz);
	vec3 rgbB = rgbA * (1.0/2.0) + (1.0/4.0) * (
		texture2D(tex0, var_texcoord0.xy + dir * (0.0/3.0 - 0.5)).xyz +
		texture2D(tex0, var_texcoord0.xy + dir * (3.0/3.0 - 0.5)).xyz);
	float lumaB = dot(rgbB, luma);

	vec4 color;

	if((lumaB < lumaMin) || (lumaB > lumaMax)){
		color.rgb = rgbA;
	}else{
		color.rgb = rgbB;
	}
	return color;
}

vec4 apply_brightness_contrast(vec4 color)
{
	lowp vec4 tint_pm = vec4(tint.xyz * tint.w, tint.w);

	// default is 1.0, increase or decrease
	float brightness = 1.0; 
	float saturation = 0.9; 
	float contrast = 1.1;
	// Increase or decrease theese values to adjust r, g and b color channels seperately
	// default is 0.5 for each
	const float AvgLumR = 0.5;
	const float AvgLumG = 0.5;
	const float AvgLumB = 0.5;

	const vec3 LumCoeff = vec3(0.2125, 0.7154, 0.0721);

	vec3 AvgLumin = vec3(AvgLumR, AvgLumG, AvgLumB);
	vec3 brtColor = color.rgb * brightness;
	vec3 intensity = vec3(dot(brtColor, LumCoeff));
	vec3 satColor = mix(intensity, brtColor, saturation);
	vec3 conColor = mix(AvgLumin, satColor, contrast);

	vec4 final_color = vec4(conColor.r, conColor.g, conColor.b, color.a);
	return final_color * tint_pm;
}

void main()
{
	gl_FragColor = vec4(texture2D(tex0,var_texcoord0).rgb, 1.0);
}
