varying mediump vec3 var_pos_world;

uniform mediump vec4 camera_pos;
uniform mediump samplerCube env;


vec2 GammaToLinearSpace (vec2 sRGB)
{
    // Approximate version from http://chilliant.blogspot.com.au/2012/08/srgb-approximations-for-hlsl.html?m=1
    return sRGB * (sRGB * (sRGB * 0.305306011 + 0.682171111) + 0.012522878);
}

vec3 GammaToLinearSpace (vec3 sRGB)
{
    // Approximate version from http://chilliant.blogspot.com.au/2012/08/srgb-approximations-for-hlsl.html?m=1
    return sRGB * (sRGB * (sRGB * 0.305306011 + 0.682171111) + 0.012522878);
}

vec4 GammaToLinearSpace (vec4 sRGB)
{
    return vec4(GammaToLinearSpace(sRGB.rgb), sRGB.a);
}


vec3 LinearToGammaSpace (vec3 linRGB)
{
    linRGB = max(linRGB, vec3(0.0, 0.0, 0.0));
    // An almost-perfect approximation from http://chilliant.blogspot.com.au/2012/08/srgb-approximations-for-hlsl.html?m=1
    return max(1.055 * pow(linRGB, vec3(0.416666667)) - 0.055, 0.0);

    // Exact version, useful for debugging.
    //return half3(LinearToGammaSpaceExact(linRGB.r), LinearToGammaSpaceExact(linRGB.g), LinearToGammaSpaceExact(linRGB.b));
}


vec3 decodeHDR(vec4 rgbm)
{
    return 5.0 * rgbm.rgb * rgbm.a;
}



vec3 Environment(samplerCube env, vec3 reflUVW)
{
    //to match DX coordinate handedness, which inherit from DDS texture
    return decodeHDR(GammaToLinearSpace(textureCube(env, reflUVW.zyx)));
}


void main()
{
    vec3 reflUVW = normalize(var_pos_world - camera_pos.xyz);
    vec3 specular =Environment(env, reflUVW);
    gl_FragColor = vec4(LinearToGammaSpace(specular), 1);
    //gl_FragColor = vec4((reflUVW + vec3(1.0)) * 0.5, 1);
    //gl_FragColor = vec4(1, 0, 0, 1);
}
